# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`letsencrypt`](#letsencrypt): Install and configure Certbot, the LetsEncrypt client
* [`letsencrypt::install`](#letsencryptinstall): Installs the Let's Encrypt client.
* [`letsencrypt::plugin::dns_cloudflare`](#letsencryptplugindns_cloudflare): Installs and configures the dns-cloudflare plugin
* [`letsencrypt::plugin::dns_rfc2136`](#letsencryptplugindns_rfc2136): Installs and configures the dns-rfc2136 plugin
* [`letsencrypt::plugin::dns_route53`](#letsencryptplugindns_route53): Installs and configures the dns-route53 plugin
* [`letsencrypt::plugin::nginx`](#letsencryptpluginnginx): install and configure the Let's Encrypt nginx plugin
* [`letsencrypt::renew`](#letsencryptrenew): Configures renewal of Let's Encrypt certificates using Certbot

#### Private Classes

* `letsencrypt::config`: Configures the Let's Encrypt client.
* `letsencrypt::scripts`: Deploy helper scripts scripts

### Defined types

* [`letsencrypt::certonly`](#letsencryptcertonly): Request a certificate using the `certonly` installer
* [`letsencrypt::hook`](#letsencrypthook): Creates hook scripts.

### Functions

* [`letsencrypt::letsencrypt_lookup`](#letsencryptletsencrypt_lookup)

### Data types

* [`Letsencrypt::Cron::Hour`](#letsencryptcronhour): mimic hour setting in cron as defined in man 5 crontab
* [`Letsencrypt::Cron::Minute`](#letsencryptcronminute): mimic minute setting in cron as defined in man 5 crontab
* [`Letsencrypt::Cron::Monthday`](#letsencryptcronmonthday): mimic monthday setting in cron as defined in man 5 crontab
* [`Letsencrypt::Plugin`](#letsencryptplugin): List of accepted plugins

## Classes

### <a name="letsencrypt"></a>`letsencrypt`

Install and configure Certbot, the LetsEncrypt client

#### Examples

##### 

```puppet
class { 'letsencrypt' :
  email  => 'letsregister@example.com',
  config => {
    'server' => 'https://acme-staging-v02.api.letsencrypt.org/directory',
  },
}
```

#### Parameters

The following parameters are available in the `letsencrypt` class:

* [`email`](#email)
* [`environment`](#environment)
* [`package_name`](#package_name)
* [`package_ensure`](#package_ensure)
* [`package_command`](#package_command)
* [`config_file`](#config_file)
* [`config`](#config)
* [`cron_scripts_path`](#cron_scripts_path)
* [`cron_owner_group`](#cron_owner_group)
* [`manage_config`](#manage_config)
* [`manage_install`](#manage_install)
* [`configure_epel`](#configure_epel)
* [`agree_tos`](#agree_tos)
* [`unsafe_registration`](#unsafe_registration)
* [`config_dir`](#config_dir)
* [`key_size`](#key_size)
* [`certificates`](#certificates)
* [`renew_pre_hook_commands`](#renew_pre_hook_commands)
* [`renew_post_hook_commands`](#renew_post_hook_commands)
* [`renew_deploy_hook_commands`](#renew_deploy_hook_commands)
* [`renew_additional_args`](#renew_additional_args)
* [`renew_cron_ensure`](#renew_cron_ensure)
* [`renew_cron_hour`](#renew_cron_hour)
* [`renew_cron_minute`](#renew_cron_minute)
* [`renew_cron_monthday`](#renew_cron_monthday)

##### <a name="email"></a>`email`

Data type: `Optional[String]`

The email address to use to register with Let's Encrypt. This takes
precedence over an 'email' setting defined in $config.

Default value: ``undef``

##### <a name="environment"></a>`environment`

Data type: `Array`

An optional array of environment variables

Default value: `[]`

##### <a name="package_name"></a>`package_name`

Data type: `String`

Name of package and command to use when installing the client package.

Default value: `'certbot'`

##### <a name="package_ensure"></a>`package_ensure`

Data type: `Any`

The value passed to `ensure` when installing the client package.

Default value: `'installed'`

##### <a name="package_command"></a>`package_command`

Data type: `String`

Path or name for letsencrypt executable.

Default value: `'certbot'`

##### <a name="config_file"></a>`config_file`

Data type: `String`

The path to the configuration file for the letsencrypt cli.

Default value: `"${config_dir}/cli.ini"`

##### <a name="config"></a>`config`

Data type: `Hash`

A hash representation of the letsencrypt configuration file.

Default value: `{ 'server' => 'https://acme-v02.api.letsencrypt.org/directory' }`

##### <a name="cron_scripts_path"></a>`cron_scripts_path`

Data type: `String`

The path for renewal scripts called by cron

Default value: `"${facts['puppet_vardir']}/letsencrypt"`

##### <a name="cron_owner_group"></a>`cron_owner_group`

Data type: `String`

Group owner of cron renew scripts.

Default value: `'root'`

##### <a name="manage_config"></a>`manage_config`

Data type: `Boolean`

A feature flag to toggle the management of the letsencrypt configuration file.

Default value: ``true``

##### <a name="manage_install"></a>`manage_install`

Data type: `Boolean`

A feature flag to toggle the management of the letsencrypt client installation.

Default value: ``true``

##### <a name="configure_epel"></a>`configure_epel`

Data type: `Boolean`

A feature flag to include the 'epel' class and depend on it for package installation.

##### <a name="agree_tos"></a>`agree_tos`

Data type: `Boolean`

A flag to agree to the Let's Encrypt Terms of Service.

Default value: ``true``

##### <a name="unsafe_registration"></a>`unsafe_registration`

Data type: `Boolean`

A flag to allow using the 'register-unsafely-without-email' flag.

Default value: ``false``

##### <a name="config_dir"></a>`config_dir`

Data type: `Stdlib::Unixpath`

The path to the configuration directory.

Default value: `'/etc/letsencrypt'`

##### <a name="key_size"></a>`key_size`

Data type: `Integer[2048]`

Size for the RSA public key

Default value: `4096`

##### <a name="certificates"></a>`certificates`

Data type: `Hash[String[1],Hash]`

A hash containing certificates. Each key is the title and each value is a hash, both passed to letsencrypt::certonly.

Default value: `{}`

##### <a name="renew_pre_hook_commands"></a>`renew_pre_hook_commands`

Data type: `Any`

Array of commands to run in a shell before obtaining/renewing any certificates.

Default value: `[]`

##### <a name="renew_post_hook_commands"></a>`renew_post_hook_commands`

Data type: `Any`

Array of commands to run in a shell after attempting to obtain/renew certificates.

Default value: `[]`

##### <a name="renew_deploy_hook_commands"></a>`renew_deploy_hook_commands`

Data type: `Any`

Array of commands to run in a shell once for each successfully issued/renewed
certificate. Two environmental variables are supplied by certbot:
- $RENEWED_LINEAGE: Points to the live directory with the cert files and key.
                    Example: /etc/letsencrypt/live/example.com
- $RENEWED_DOMAINS: A space-delimited list of renewed certificate domains.
                    Example: "example.com www.example.com"

Default value: `[]`

##### <a name="renew_additional_args"></a>`renew_additional_args`

Data type: `Any`

Array of additional command line arguments to pass to 'certbot renew'.

Default value: `[]`

##### <a name="renew_cron_ensure"></a>`renew_cron_ensure`

Data type: `Any`

Intended state of the cron resource running certbot renew.

Default value: `'absent'`

##### <a name="renew_cron_hour"></a>`renew_cron_hour`

Data type: `Any`

Optional string, integer or array of hour(s) the renewal command should run.
E.g. '[0,12]' to execute at midnight and midday.
hour.

Default value: `fqdn_rand(24)`

##### <a name="renew_cron_minute"></a>`renew_cron_minute`

Data type: `Any`

Optional string, integer or array of minute(s) the renewal command should
run. E.g. 0 or '00' or [0,30].

Default value: `fqdn_rand(60)`

##### <a name="renew_cron_monthday"></a>`renew_cron_monthday`

Data type: `Any`

Optional string, integer or array of monthday(s) the renewal command should
run. E.g. '2-30/2' to run on even days.

Default value: `'*'`

### <a name="letsencryptinstall"></a>`letsencrypt::install`

Installs the Let's Encrypt client.

#### Parameters

The following parameters are available in the `letsencrypt::install` class:

* [`configure_epel`](#configure_epel)
* [`package_ensure`](#package_ensure)
* [`package_name`](#package_name)

##### <a name="configure_epel"></a>`configure_epel`

Data type: `Boolean`

A feature flag to include the 'epel' class and depend on it for package installation.

Default value: `$letsencrypt::configure_epel`

##### <a name="package_ensure"></a>`package_ensure`

Data type: `String`

The value passed to `ensure` when installing the client package.

Default value: `$letsencrypt::package_ensure`

##### <a name="package_name"></a>`package_name`

Data type: `String`

Name of package to use when installing the client package.

Default value: `$letsencrypt::package_name`

### <a name="letsencryptplugindns_cloudflare"></a>`letsencrypt::plugin::dns_cloudflare`

This class installs and configures the Let's Encrypt dns-cloudflare plugin.
https://certbot-dns-cloudflare.readthedocs.io

#### Parameters

The following parameters are available in the `letsencrypt::plugin::dns_cloudflare` class:

* [`package_name`](#package_name)
* [`api_key`](#api_key)
* [`api_token`](#api_token)
* [`email`](#email)
* [`config_dir`](#config_dir)
* [`manage_package`](#manage_package)
* [`propagation_seconds`](#propagation_seconds)
* [`config_path`](#config_path)

##### <a name="package_name"></a>`package_name`

Data type: `Optional[String[1]]`

The name of the package to install when $manage_package is true.

Default value: ``undef``

##### <a name="api_key"></a>`api_key`

Data type: `Optional[String[1]]`

Optional string, cloudflare api key value for authentication.

Default value: ``undef``

##### <a name="api_token"></a>`api_token`

Data type: `Optional[String[1]]`

Optional string, cloudflare api token value for authentication.

Default value: ``undef``

##### <a name="email"></a>`email`

Data type: `Optional[String[1]]`

Optional string, cloudflare account email address, used in conjunction with api_key.

Default value: ``undef``

##### <a name="config_dir"></a>`config_dir`

The path to the configuration directory.

##### <a name="manage_package"></a>`manage_package`

Data type: `Boolean`

Manage the plugin package.

Default value: ``true``

##### <a name="propagation_seconds"></a>`propagation_seconds`

Data type: `Integer`

Number of seconds to wait for the DNS server to propagate the DNS-01 challenge.

Default value: `10`

##### <a name="config_path"></a>`config_path`

Data type: `Stdlib::Absolutepath`



Default value: `"${letsencrypt::config_dir}/dns-cloudflare.ini"`

### <a name="letsencryptplugindns_rfc2136"></a>`letsencrypt::plugin::dns_rfc2136`

This class installs and configures the Let's Encrypt dns-rfc2136 plugin.
https://certbot-dns-rfc2136.readthedocs.io

#### Parameters

The following parameters are available in the `letsencrypt::plugin::dns_rfc2136` class:

* [`server`](#server)
* [`key_name`](#key_name)
* [`key_secret`](#key_secret)
* [`key_algorithm`](#key_algorithm)
* [`port`](#port)
* [`propagation_seconds`](#propagation_seconds)
* [`manage_package`](#manage_package)
* [`package_name`](#package_name)
* [`config_dir`](#config_dir)

##### <a name="server"></a>`server`

Data type: `Stdlib::Host`

Target DNS server.

##### <a name="key_name"></a>`key_name`

Data type: `String[1]`

TSIG key name.

##### <a name="key_secret"></a>`key_secret`

Data type: `String[1]`

TSIG key secret.

##### <a name="key_algorithm"></a>`key_algorithm`

Data type: `String[1]`

TSIG key algorithm.

Default value: `'HMAC-SHA512'`

##### <a name="port"></a>`port`

Data type: `Stdlib::Port`

Target DNS port.

Default value: `53`

##### <a name="propagation_seconds"></a>`propagation_seconds`

Data type: `Integer`

Number of seconds to wait for the DNS server to propagate the DNS-01 challenge. (the plugin defaults to 60)

Default value: `10`

##### <a name="manage_package"></a>`manage_package`

Data type: `Boolean`

Manage the plugin package.

Default value: ``true``

##### <a name="package_name"></a>`package_name`

Data type: `String[1]`

The name of the package to install when $manage_package is true.

##### <a name="config_dir"></a>`config_dir`

Data type: `Stdlib::Absolutepath`

The path to the configuration directory.

Default value: `$letsencrypt::config_dir`

### <a name="letsencryptplugindns_route53"></a>`letsencrypt::plugin::dns_route53`

This class installs and configures the Let's Encrypt dns-route53 plugin.
https://certbot-dns-route53.readthedocs.io

#### Parameters

The following parameters are available in the `letsencrypt::plugin::dns_route53` class:

* [`propagation_seconds`](#propagation_seconds)
* [`manage_package`](#manage_package)
* [`package_name`](#package_name)

##### <a name="propagation_seconds"></a>`propagation_seconds`

Data type: `Integer`

Number of seconds to wait for the DNS server to propagate the DNS-01 challenge.

Default value: `10`

##### <a name="manage_package"></a>`manage_package`

Data type: `Boolean`

Manage the plugin package.

Default value: ``true``

##### <a name="package_name"></a>`package_name`

Data type: `String[1]`

The name of the package to install when $manage_package is true.

### <a name="letsencryptpluginnginx"></a>`letsencrypt::plugin::nginx`

install and configure the Let's Encrypt nginx plugin

#### Parameters

The following parameters are available in the `letsencrypt::plugin::nginx` class:

* [`manage_package`](#manage_package)
* [`package_name`](#package_name)

##### <a name="manage_package"></a>`manage_package`

Data type: `Boolean`

Manage the plugin package.

Default value: ``true``

##### <a name="package_name"></a>`package_name`

Data type: `String[1]`

The name of the package to install when $manage_package is true.

Default value: `'python3-certbot-nginx'`

### <a name="letsencryptrenew"></a>`letsencrypt::renew`

Configures renewal of Let's Encrypt certificates using the certbot renew command.

Note: Hooks set here will run before/after/for ALL certificates, including
any not managed by Puppet. If you want to create hooks for specific
certificates only, create them using letsencrypt::certonly.

#### Parameters

The following parameters are available in the `letsencrypt::renew` class:

* [`pre_hook_commands`](#pre_hook_commands)
* [`post_hook_commands`](#post_hook_commands)
* [`deploy_hook_commands`](#deploy_hook_commands)
* [`additional_args`](#additional_args)
* [`cron_ensure`](#cron_ensure)
* [`cron_hour`](#cron_hour)
* [`cron_minute`](#cron_minute)
* [`cron_monthday`](#cron_monthday)

##### <a name="pre_hook_commands"></a>`pre_hook_commands`

Data type: `Variant[String[1], Array[String[1]]]`

Array of commands to run in a shell before obtaining/renewing any certificates.

Default value: `$letsencrypt::renew_pre_hook_commands`

##### <a name="post_hook_commands"></a>`post_hook_commands`

Data type: `Variant[String[1], Array[String[1]]]`

Array of commands to run in a shell after attempting to obtain/renew certificates.

Default value: `$letsencrypt::renew_post_hook_commands`

##### <a name="deploy_hook_commands"></a>`deploy_hook_commands`

Data type: `Variant[String[1], Array[String[1]]]`

Array of commands to run in a shell once for each successfully issued/renewed
certificate. Two environmental variables are supplied by certbot:
- $RENEWED_LINEAGE: Points to the live directory with the cert files and key.
                    Example: /etc/letsencrypt/live/example.com
- $RENEWED_DOMAINS: A space-delimited list of renewed certificate domains.
                    Example: "example.com www.example.com"

Default value: `$letsencrypt::renew_deploy_hook_commands`

##### <a name="additional_args"></a>`additional_args`

Data type: `Array[String[1]]`

Array of additional command line arguments to pass to 'certbot renew'.

Default value: `$letsencrypt::renew_additional_args`

##### <a name="cron_ensure"></a>`cron_ensure`

Data type: `Enum['present', 'absent']`

Intended state of the cron resource running certbot renew

Default value: `$letsencrypt::renew_cron_ensure`

##### <a name="cron_hour"></a>`cron_hour`

Data type: `Letsencrypt::Cron::Hour`

Optional string, integer or array of hour(s) the renewal command should run.
E.g. '[0,12]' to execute at midnight and midday. Default: fqdn-seeded random hour.

Default value: `$letsencrypt::renew_cron_hour`

##### <a name="cron_minute"></a>`cron_minute`

Data type: `Letsencrypt::Cron::Minute`

Optional string, integer or array of minute(s) the renewal command should
run. E.g. 0 or '00' or [0,30]. Default: fqdn-seeded random minute.

Default value: `$letsencrypt::renew_cron_minute`

##### <a name="cron_monthday"></a>`cron_monthday`

Data type: `Letsencrypt::Cron::Monthday`

Optional string, integer or array of monthday(s) the renewal command should
run. E.g. '2-30/2' to run on even days. Default: Every day.

Default value: `$letsencrypt::renew_cron_monthday`

## Defined types

### <a name="letsencryptcertonly"></a>`letsencrypt::certonly`

This type can be used to request a certificate using the `certonly` installer.

#### Examples

##### standalone authenticator

```puppet
# Request a certificate for `foo.example.com` using the `certonly`
# installer and the `standalone` authenticator.
letsencrypt::certonly { 'foo.example.com': }
```

##### Multiple domains

```puppet
# Request a certificate for `foo.example.com` and `bar.example.com` using
# the `certonly` installer and the `standalone` authenticator.
letsencrypt::certonly { 'foo':
  domains => ['foo.example.com', 'bar.example.com'],
}
```

##### Apache authenticator

```puppet
# Request a certificate for `foo.example.com` with the `certonly` installer
# and the `apache` authenticator.
letsencrypt::certonly { 'foo.example.com':
  plugin  => 'apache',
}
```

##### Nginx authenticator

```puppet
# Request a certificate for `foo.example.com` with the `certonly` installer
# and the `nginx` authenticator.
letsencrypt::certonly { 'foo.example.com':
  plugin  => 'nginx',
}
```

##### webroot authenticator

```puppet
# Request a certificate using the `webroot` authenticator. The paths to the
# webroots for all domains must be given through `webroot_paths`. If
# `domains` and `webroot_paths` are not the same length, the last
# `webroot_paths` element will be used for all subsequent domains.
letsencrypt::certonly { 'foo':
  domains       => ['foo.example.com', 'bar.example.com'],
  plugin        => 'webroot',
  webroot_paths => ['/var/www/foo', '/var/www/bar'],
}
```

##### dns-rfc2136 authenticator

```puppet
# Request a certificate using the `dns-rfc2136` authenticator. Ideally the
# key `secret` should be encrypted, eg. with eyaml if using Hiera. It's
# also recommended to only enable access to the specific DNS records needed
# by the Let's Encrypt client.
#
# [Plugin documentation](https://certbot-dns-rfc2136.readthedocs.io)
class { 'letsencrypt::plugin::dns_rfc2136':
  server     => '192.0.2.1',
  key_name   => 'certbot',
  key_secret => '[...]==',
}

letsencrypt::certonly { 'foo.example.com':
  plugin        => 'dns-rfc2136',
}
```

##### dns-route53 authenticator

```puppet
# Request a certificate for `foo.example.com` with the `certonly` installer
# and the `dns-route53` authenticator.
letsencrypt::certonly { 'foo.example.com':
  plugin  => 'dns-route53',
}
```

##### Additional arguments

```puppet
# If you need to pass a command line flag to the `certbot` command that
# is not supported natively by this module, you can use the
# `additional_args` parameter to pass those arguments.
letsencrypt::certonly { 'foo.example.com':
  additional_args => ['--foo bar', '--baz quuz'],
}
```

#### Parameters

The following parameters are available in the `letsencrypt::certonly` defined type:

* [`ensure`](#ensure)
* [`domains`](#domains)
* [`custom_plugin`](#custom_plugin)
* [`plugin`](#plugin)
* [`webroot_paths`](#webroot_paths)
* [`letsencrypt_command`](#letsencrypt_command)
* [`additional_args`](#additional_args)
* [`environment`](#environment)
* [`key_size`](#key_size)
* [`manage_cron`](#manage_cron)
* [`cron_output`](#cron_output)
* [`cron_before_command`](#cron_before_command)
* [`cron_success_command`](#cron_success_command)
* [`cron_hour`](#cron_hour)
* [`cron_minute`](#cron_minute)
* [`cron_monthday`](#cron_monthday)
* [`config_dir`](#config_dir)
* [`pre_hook_commands`](#pre_hook_commands)
* [`post_hook_commands`](#post_hook_commands)
* [`deploy_hook_commands`](#deploy_hook_commands)
* [`cert_name`](#cert_name)

##### <a name="ensure"></a>`ensure`

Data type: `Enum['present','absent']`

Intended state of the resource
Will remove certificates for specified domains if set to 'absent'. Will
also remove cronjobs and renewal scripts if `manage_cron` is set to 'true'.

Default value: `'present'`

##### <a name="domains"></a>`domains`

Data type: `Array[String[1]]`

An array of domains to include in the CSR.

Default value: `[$title]`

##### <a name="custom_plugin"></a>`custom_plugin`

Data type: `Boolean`

Whether to use a custom plugin in additional_args and disable -a flag.

Default value: ``false``

##### <a name="plugin"></a>`plugin`

Data type: `Letsencrypt::Plugin`

The authenticator plugin to use when requesting the certificate.

Default value: `'standalone'`

##### <a name="webroot_paths"></a>`webroot_paths`

Data type: `Array[Stdlib::Unixpath]`

An array of webroot paths for the domains in `domains`.
Required if using `plugin => 'webroot'`. If `domains` and
`webroot_paths` are not the same length, the last `webroot_paths`
element will be used for all subsequent domains.

Default value: `[]`

##### <a name="letsencrypt_command"></a>`letsencrypt_command`

Data type: `String[1]`

Command to run letsencrypt

Default value: `$letsencrypt::command`

##### <a name="additional_args"></a>`additional_args`

Data type: `Array[String[1]]`

An array of additional command line arguments to pass to the `letsencrypt` command.

Default value: `[]`

##### <a name="environment"></a>`environment`

Data type: `Array[String[1]]`

An optional array of environment variables

Default value: `[]`

##### <a name="key_size"></a>`key_size`

Data type: `Integer[2048]`

Size for the RSA public key

Default value: `$letsencrypt::key_size`

##### <a name="manage_cron"></a>`manage_cron`

Data type: `Boolean`

Indicating whether or not to schedule cron job for renewal.
Runs daily but only renews if near expiration, e.g. within 10 days.

Default value: ``false``

##### <a name="cron_output"></a>`cron_output`

Data type: `Optional[Enum['suppress', 'log']]`

How to treat cron output
`suppress` - Suppress all output
`log` - Forward cron output to syslog
undef - Do nothing with cron output (default)

Default value: ``undef``

##### <a name="cron_before_command"></a>`cron_before_command`

Data type: `Optional[String[1]]`

Representation of a command that should be run before renewal command

Default value: ``undef``

##### <a name="cron_success_command"></a>`cron_success_command`

Data type: `Optional[String[1]]`

Representation of a command that should be run if the renewal command succeeds.

Default value: ``undef``

##### <a name="cron_hour"></a>`cron_hour`

Data type: `Variant[Integer[0,23], String, Array]`

Optional hour(s) that the renewal command should execute.
e.g. '[0,12]' execute at midnight and midday.  Default - seeded random hour.

Default value: `fqdn_rand(24, $title)`

##### <a name="cron_minute"></a>`cron_minute`

Data type: `Variant[Integer[0,59], String, Array]`

Optional minute(s) that the renewal command should execute.
e.g. 0 or '00' or [0,30].  Default - seeded random minute.

Default value: `fqdn_rand(60, $title)`

##### <a name="cron_monthday"></a>`cron_monthday`

Data type: `Array[Variant[Integer[0, 59], String[1]]]`

Optional string, integer or array of monthday(s) the renewal command should
run. E.g. '2-30/2' to run on even days. Default: Every day.

Default value: `['*']`

##### <a name="config_dir"></a>`config_dir`

Data type: `Stdlib::Unixpath`

The path to the configuration directory.

Default value: `$letsencrypt::config_dir`

##### <a name="pre_hook_commands"></a>`pre_hook_commands`

Data type: `Variant[String[1], Array[String[1]]]`

Array of commands to run in a shell before attempting to obtain/renew the certificate.

Default value: `[]`

##### <a name="post_hook_commands"></a>`post_hook_commands`

Data type: `Variant[String[1], Array[String[1]]]`

Array of command(s) to run in a shell after attempting to obtain/renew the certificate.

Default value: `[]`

##### <a name="deploy_hook_commands"></a>`deploy_hook_commands`

Data type: `Variant[String[1], Array[String[1]]]`

Array of command(s) to run in a shell once if the certificate is successfully issued.
Two environmental variables are supplied by certbot:
- $RENEWED_LINEAGE: Points to the live directory with the cert files and key.
                    Example: /etc/letsencrypt/live/example.com
- $RENEWED_DOMAINS: A space-delimited list of renewed certificate domains.
                    Example: "example.com www.example.com"

Default value: `[]`

##### <a name="cert_name"></a>`cert_name`

Data type: `String[1]`



Default value: `$title`

### <a name="letsencrypthook"></a>`letsencrypt::hook`

This type is used by letsencrypt::renew and letsencrypt::certonly to create hook scripts.

#### Parameters

The following parameters are available in the `letsencrypt::hook` defined type:

* [`type`](#type)
* [`hook_file`](#hook_file)
* [`commands`](#commands)

##### <a name="type"></a>`type`

Data type: `Enum['pre', 'post', 'deploy']`

Hook type.

##### <a name="hook_file"></a>`hook_file`

Data type: `String[1]`

Path to deploy hook script.

##### <a name="commands"></a>`commands`

Data type: `Variant[String[1],Array[String[1]]]`

Bash commands to execute when the hook is run by certbot.

## Functions

### <a name="letsencryptletsencrypt_lookup"></a>`letsencrypt::letsencrypt_lookup`

Type: Ruby 4.x API

The letsencrypt::letsencrypt_lookup function.

#### `letsencrypt::letsencrypt_lookup(Any $common_name)`

The letsencrypt::letsencrypt_lookup function.

Returns: `Any`

##### `common_name`

Data type: `Any`



## Data types

### <a name="letsencryptcronhour"></a>`Letsencrypt::Cron::Hour`

mimic hour setting in cron as defined in man 5 crontab

Alias of

```puppet
Variant[Integer[0,23], String[1], Array[
    Variant[
      Integer[0,23],
      String[1],
    ]
  ]]
```

### <a name="letsencryptcronminute"></a>`Letsencrypt::Cron::Minute`

mimic minute setting in cron as defined in man 5 crontab

Alias of

```puppet
Variant[Integer[0,59], String[1], Array[
    Variant[
      Integer[0,59],
      String[1],
    ]
  ]]
```

### <a name="letsencryptcronmonthday"></a>`Letsencrypt::Cron::Monthday`

mimic monthday setting in cron as defined in man 5 crontab

Alias of

```puppet
Variant[Integer[0,31], String[1], Array[
    Variant[
      Integer[0,31],
      String[1],
    ]
  ]]
```

### <a name="letsencryptplugin"></a>`Letsencrypt::Plugin`

List of accepted plugins

Alias of

```puppet
Enum['apache', 'standalone', 'webroot', 'nginx', 'dns-route53', 'dns-google', 'dns-cloudflare', 'dns-rfc2136', 'manual']
```

